'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-0e20a87a.js');
const defaultIconPack = require('./default-icon-pack-d94ddba8.js');
const index$1 = require('./index-211dabb8.js');
const logger = require('./logger-0e4a4217.js');

const dyteScreenShareToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const deviceCanScreenShare = () => {
  return (typeof navigator !== 'undefined' &&
    typeof navigator.mediaDevices !== 'undefined' &&
    'getDisplayMedia' in navigator.mediaDevices);
};
const DyteScreenShareToggle = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$1.useLanguage();
    this.screenShareEnabled = false;
    this.canScreenShare = false;
  }
  connectedCallback() {
    if (!deviceCanScreenShare()) {
      logger.loglevel.error('[dyte-screenshare-toggle] Device does not support screensharing.');
    }
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.screenShareListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('screenShareUpdate', this.screenShareListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canScreenShare =
        deviceCanScreenShare() && meeting.self.permissions.produceScreenshare.allow;
      this.screenShareEnabled = self.screenShareEnabled;
      this.screenShareListener = ({ screenShareEnabled }) => {
        this.screenShareEnabled = screenShareEnabled;
      };
      self.addListener('screenShareUpdate', this.screenShareListener);
    }
  }
  toggleScreenShare() {
    var _a;
    const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
    if (self == null || !this.canScreenShare) {
      return;
    }
    if (self.screenShareEnabled) {
      self.disableScreenShare();
    }
    else {
      self.enableScreenShare();
    }
  }
  render() {
    if (!this.canScreenShare) {
      return null;
    }
    const text = this.t(this.screenShareEnabled ? 'share_screen_stop' : 'share_screen_start');
    return (index.h(index.Host, { title: text }, index.h("dyte-controlbar-button", { size: this.size, class: {
        'red-icon': this.screenShareEnabled,
      }, onClick: () => this.toggleScreenShare(), icon: this.screenShareEnabled
        ? this.iconPack.share_screen_stop
        : this.iconPack.share_screen_start, label: text })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteScreenShareToggle.style = dyteScreenShareToggleCss;

exports.dyte_screen_share_toggle = DyteScreenShareToggle;
