import { Component, Host, h, Prop } from '@stencil/core';
import { ChatHead } from '../dyte-chat/components/ChatHead';
import { sanitizeLink } from '../../utils/string';
import { defaultIconPack } from '../../lib/icons';
import { downloadFile, getExtension, getFileSize } from '../../utils/file';
export class DyteFileMessage {
  constructor() {
    /** Date object of now, to calculate distance between dates */
    this.now = new Date();
    /** Whether the message is continued by same user */
    this.isContinued = false;
    /** Icon pack */
    this.iconPack = defaultIconPack;
  }
  render() {
    const link = sanitizeLink(this.message.link);
    return (h(Host, null,
      !this.isContinued && (h(ChatHead, { name: this.message.displayName, time: this.message.time, now: this.now })),
      h("div", { class: "body" },
        h("div", { class: "file" },
          h("div", { class: "file-data" },
            h("div", { class: "name" }, this.message.name),
            h("div", { class: "file-data-split" },
              h("div", { class: "ext" }, getExtension(this.message.name)),
              h("span", { class: "divider" }),
              h("div", { class: "size" }, getFileSize(this.message.size)))),
          h("dyte-button", { variant: "outline", kind: "icon", onClick: () => downloadFile(link, { name: this.message.name, fallbackName: 'file' }) },
            h("dyte-icon", { icon: this.iconPack.download }))))));
  }
  static get is() { return "dyte-file-message"; }
  static get properties() { return {
    "message": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "FileMessage",
        "resolved": "FileMessage",
        "references": {
          "FileMessage": {
            "location": "import",
            "path": "@dyte-in/client-core/types/client/DyteChat"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Text message object"
      }
    },
    "now": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Date",
        "resolved": "Date",
        "references": {
          "Date": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Date object of now, to calculate distance between dates"
      },
      "defaultValue": "new Date()"
    },
    "isContinued": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the message is continued by same user"
      },
      "attribute": "is-continued",
      "reflect": true,
      "defaultValue": "false"
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    }
  }; }
}
