import { defaultIconPack } from '../../lib/icons';
import { Component, Host, h, Prop, Watch, State } from '@stencil/core';
export class DytePluginMain {
  constructor() {
    /** Icon pack */
    this.iconPack = defaultIconPack;
    this.canClosePlugin = false;
  }
  componentDidLoad() {
    this.meetingChanged(this.meeting);
    this.pluginChanged(this.plugin);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canClosePlugin = meeting.self.permissions.plugins.canClose;
    }
  }
  pluginChanged(plugin) {
    if (plugin != null) {
      plugin.addPluginView(this.iframeEl);
    }
  }
  render() {
    if (this.plugin == null)
      return null;
    return (h(Host, null,
      h("header", null,
        h("div", null, this.plugin.name),
        this.canClosePlugin && (h("div", null,
          h("dyte-button", { kind: "icon", onClick: () => this.plugin.deactivate() },
            h("dyte-icon", { icon: this.iconPack.dismiss }))))),
      h("iframe", { ref: (el) => (this.iframeEl = el) })));
  }
  static get is() { return "dyte-plugin-main"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-plugin-main.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-plugin-main.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting"
      }
    },
    "plugin": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "DytePlugin",
        "resolved": "{ readonly baseURL: string; readonly createdAt: Date; readonly description: string; readonly id: string; readonly name: string; readonly organizationId: string; readonly picture: string; readonly private: boolean; readonly published: boolean; readonly staggered: boolean; readonly tags: string[]; readonly type: string; readonly updatedAt: Date; readonly config?: PluginConfig; readonly active: boolean; readonly iframes: Map<string, { iframe: HTMLIFrameElement; listener: (message: MessageEvent<any>) => void; }>; readonly sendIframeEvent: (message: WebsocketMessage) => void; readonly removePluginView: (viewId?: string) => void; readonly addPluginView: (iframe: HTMLIFrameElement, viewId?: string) => void; readonly enable: () => Promise<void>; readonly disable: () => void; readonly activate: () => Promise<void>; readonly deactivate: () => Promise<void>; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => void) => DytePlugin; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DytePlugin; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DytePlugin; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DytePlugin; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DytePlugin; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DytePlugin; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DytePlugin; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => DytePlugin; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => number; readonly setMaxListeners: (n: number) => DytePlugin; readonly getMaxListeners: () => number; readonly rawListeners: (event: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; }",
        "references": {
          "DytePlugin": {
            "location": "import",
            "path": "@dyte-in/client-core"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Plugin"
      }
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    }
  }; }
  static get states() { return {
    "canClosePlugin": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }, {
      "propName": "plugin",
      "methodName": "pluginChanged"
    }]; }
}
