import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import logger from '../../utils/logger';
const deviceCanScreenShare = () => {
  return (typeof navigator !== 'undefined' &&
    typeof navigator.mediaDevices !== 'undefined' &&
    'getDisplayMedia' in navigator.mediaDevices);
};
export class DyteScreenShareToggle {
  constructor() {
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.screenShareEnabled = false;
    this.canScreenShare = false;
  }
  connectedCallback() {
    if (!deviceCanScreenShare()) {
      logger.error('[dyte-screenshare-toggle] Device does not support screensharing.');
    }
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.screenShareListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('screenShareUpdate', this.screenShareListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canScreenShare =
        deviceCanScreenShare() && meeting.self.permissions.produceScreenshare.allow;
      this.screenShareEnabled = self.screenShareEnabled;
      this.screenShareListener = ({ screenShareEnabled }) => {
        this.screenShareEnabled = screenShareEnabled;
      };
      self.addListener('screenShareUpdate', this.screenShareListener);
    }
  }
  toggleScreenShare() {
    var _a;
    const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
    if (self == null || !this.canScreenShare) {
      return;
    }
    if (self.screenShareEnabled) {
      self.disableScreenShare();
    }
    else {
      self.enableScreenShare();
    }
  }
  render() {
    if (!this.canScreenShare) {
      return null;
    }
    const text = this.t(this.screenShareEnabled ? 'share_screen_stop' : 'share_screen_start');
    return (h(Host, { title: text },
      h("dyte-controlbar-button", { size: this.size, class: {
          'red-icon': this.screenShareEnabled,
        }, onClick: () => this.toggleScreenShare(), icon: this.screenShareEnabled
          ? this.iconPack.share_screen_stop
          : this.iconPack.share_screen_start, label: text })));
  }
  static get is() { return "dyte-screen-share-toggle"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-screen-share-toggle.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-screen-share-toggle.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "screenShareEnabled": {},
    "canScreenShare": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }]; }
}
