import { Component, Host, h, Prop, Watch, State, writeTask } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
export class DyteScreenshareView {
  constructor() {
    /** Position of name tag */
    this.nameTagPosition = 'bottom-left';
    /** Variant */
    this.variant = 'solid';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    this.screenShareEnabled = false;
  }
  componentDidLoad() {
    this.peerChanged(this.peer);
  }
  disconnectedCallback() {
    var _a;
    this.screenShareListener &&
      ((_a = this.peer) === null || _a === void 0 ? void 0 : _a.removeListener('screenShareUpdate', this.screenShareListener));
  }
  peerChanged(peer) {
    if (peer != null) {
      this.screenShareListener = ({ screenShareEnabled, screenShareTracks }) => {
        const enabled = screenShareEnabled && screenShareTracks.video != null;
        writeTask(() => {
          this.screenShareEnabled = enabled;
        });
        if (enabled) {
          const stream = new MediaStream();
          stream.addTrack(screenShareTracks.video);
          if (typeof this.videoEl !== 'undefined') {
            this.videoEl.srcObject = stream;
            this.videoEl.play();
          }
        }
        else {
          this.videoEl.srcObject = undefined;
        }
      };
      this.screenShareListener(peer);
      peer.addListener('screenShareUpdate', this.screenShareListener);
    }
  }
  render() {
    return (h(Host, null,
      h("video", { ref: (el) => (this.videoEl = el), class: {
          visible: this.screenShareEnabled,
        }, playsInline: true, autoPlay: true, muted: true }),
      h("slot", null)));
  }
  static get is() { return "dyte-screenshare-view"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-screenshare-view.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-screenshare-view.css"]
  }; }
  static get properties() { return {
    "nameTagPosition": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "| 'bottom-left'\n    | 'bottom-right'\n    | 'bottom-center'\n    | 'top-left'\n    | 'top-right'\n    | 'top-center'",
        "resolved": "\"bottom-center\" | \"bottom-left\" | \"bottom-right\" | \"top-center\" | \"top-left\" | \"top-right\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Position of name tag"
      },
      "attribute": "name-tag-position",
      "reflect": true,
      "defaultValue": "'bottom-left'"
    },
    "peer": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer",
        "resolved": "({ readonly id: string; readonly name: string; readonly clientSpecificId: any; readonly preview: Pick<LocalMediaHandler, \"audioTrack\" | \"videoTrack\" | \"audioEnabled\" | \"videoEnabled\">; readonly role: any; readonly audioTrack: MediaStreamTrack; readonly videoTrack: MediaStreamTrack; readonly screenShareTracks: { audio?: MediaStreamTrack; video?: MediaStreamTrack; }; readonly audioEnabled: boolean; readonly videoEnabled: boolean; readonly screenShareEnabled: boolean; readonly mediaPermissions: { audio?: MediaPermission; video?: MediaPermission; }; readonly permissions: DytePermissionsPreset; readonly suggestedTheme: DyteThemePreset; readonly roomJoined: boolean; readonly setName: (name: string) => void; readonly setupTracks: (options?: { video?: boolean; audio?: boolean; }) => Promise<void>; readonly enableAudio: () => Promise<void>; readonly enableVideo: () => Promise<void>; readonly enableScreenShare: () => Promise<void>; readonly disableAudio: () => Promise<void>; readonly disableVideo: () => Promise<void>; readonly disableScreenShare: () => Promise<void>; readonly enablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly disablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly getCurrentDevices: () => { audio: MediaDeviceInfo; video: MediaDeviceInfo; speaker: MediaDeviceInfo; }; readonly getAudioDevices: () => MediaDeviceInfo[]; readonly getVideoDevices: () => MediaDeviceInfo[]; readonly getSpeakerDevices: () => MediaDeviceInfo[]; readonly getDeviceById: (deviceId: string, kind: \"audio\" | \"video\" | \"speaker\") => MediaDeviceInfo; readonly getAllDevices: () => MediaDeviceInfo[]; readonly setDevice: (device: MediaDeviceInfo, preview?: boolean) => Promise<void>; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => void) => DyteSelf; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => DyteSelf; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => number; readonly setMaxListeners: (n: number) => DyteSelf; readonly getMaxListeners: () => number; readonly rawListeners: (event: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; }) | ({ readonly id: string; readonly userId: string; readonly name: string; readonly picture: string; readonly isHost: boolean; readonly clientSpecificId?: string; readonly flags: { [key: string]: string | boolean; }; readonly device: DeviceConfig; readonly videoTrack: MediaStreamTrack; readonly audioTrack: MediaStreamTrack; readonly screenShareTracks: { audio: MediaStreamTrack; video: MediaStreamTrack; }; readonly videoEnabled: boolean; readonly audioEnabled: boolean; readonly screenShareEnabled: boolean; readonly setVideoEnabled: (videoEnabled: boolean, emitEvent?: boolean) => void; readonly setAudioEnabled: (audioEnabled: boolean, emitEvent?: boolean) => void; readonly setScreenShareEnabled: (screenShareEnabled: boolean, emitEvent?: boolean) => void; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => void) => DyteParticipant; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => DyteParticipant; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => number; readonly setMaxListeners: (n: number) => DyteParticipant; readonly getMaxListeners: () => number; readonly rawListeners: (event: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; })",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Peer object"
      }
    },
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'solid' | 'gradient'",
        "resolved": "\"gradient\" | \"solid\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Variant"
      },
      "attribute": "variant",
      "reflect": true,
      "defaultValue": "'solid'"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    }
  }; }
  static get states() { return {
    "screenShareEnabled": {}
  }; }
  static get watchers() { return [{
      "propName": "peer",
      "methodName": "peerChanged"
    }]; }
}
