import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { d as defineCustomElement$2 } from './dyte-controlbar-button2.js';
import { d as defineCustomElement$1 } from './dyte-icon2.js';

const dyteCameraToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const DyteCameraToggle = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.videoEnabled = false;
    this.canProduceVideo = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.videoUpdateListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('videoUpdate', this.videoUpdateListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canProduceVideo = self.permissions.produceVideo.allow;
      this.videoEnabled = self.videoEnabled;
      this.videoUpdateListener = ({ videoEnabled }) => {
        this.videoEnabled = videoEnabled;
      };
      self.addListener('videoUpdate', this.videoUpdateListener);
    }
  }
  toggleCamera() {
    var _a;
    const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
    if (self == null || !this.canProduceVideo) {
      return;
    }
    if (self.videoEnabled) {
      self.disableVideo();
    }
    else {
      self.enableVideo();
    }
  }
  render() {
    if (!this.canProduceVideo) {
      return null;
    }
    const text = this.t(this.videoEnabled ? 'video_on' : 'video_off');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { size: this.size, class: {
        'red-icon': !this.videoEnabled,
      }, onClick: () => this.toggleCamera(), icon: this.videoEnabled ? this.iconPack.video_on : this.iconPack.video_off, label: text })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteCameraToggleCss; }
}, [1, "dyte-camera-toggle", {
    "meeting": [16],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "videoEnabled": [32],
    "canProduceVideo": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-camera-toggle", "dyte-controlbar-button", "dyte-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-camera-toggle":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteCameraToggle);
      }
      break;
    case "dyte-controlbar-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { DyteCameraToggle as D, defineCustomElement as d };
