import { r as registerInstance, w as writeTask, h, H as Host } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';

const dyteScreenshareViewCss = ":host{position:relative;display:flex;align-items:center;justify-content:center;font-family:var(--dyte-font-family, sans-serif);height:var(--dyte-space-56, 224px);overflow:hidden;border-radius:var(--dyte-border-radius-lg, 12px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-video-bg, 24 24 24) / var(--tw-bg-opacity));-webkit-animation:show 0.4s ease-in;animation:show 0.4s ease-in}::slotted(dyte-name-tag){position:absolute;left:var(--dyte-space-3, 12px);bottom:var(--dyte-space-3, 12px);opacity:0.8}video{position:absolute;height:100%;width:100%;-o-object-fit:contain;object-fit:contain}:host([variant='gradient']) ::slotted(dyte-audio-visualizer){position:absolute;top:var(--dyte-space-2, 8px);right:var(--dyte-space-2, 8px);border-radius:9999px;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity));padding:var(--dyte-space-2, 8px)}:host([variant='gradient']) ::slotted(dyte-name-tag){bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);display:flex;width:100%;align-items:center;justify-content:center;text-align:center;background-color:transparent;background-image:linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from:rgb(var(--dyte-colors-background-1000, 8 8 8));--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(var(--dyte-colors-background-1000, 8 8 8) / 0));--tw-gradient-to:transparent}:host([size='sm'][variant='gradient']) ::slotted(dyte-audio-visualizer){height:var(--dyte-space-5, 20px);width:var(--dyte-space-5, 20px)}:host(.exit){-webkit-animation:exit 0.4s ease-out;animation:exit 0.4s ease-out}video.visible{-webkit-animation:video-fadein 0.4s ease;animation:video-fadein 0.4s ease}@-webkit-keyframes video-fadein{0%{opacity:0;transform:scale(1.4) translateY(20px)}100%{opacity:1;transform:scale(1) translateY(0)}}@keyframes video-fadein{0%{opacity:0;transform:scale(1.4) translateY(20px)}100%{opacity:1;transform:scale(1) translateY(0)}}@-webkit-keyframes show{0%{opacity:0;transform:scale(0.4) translateY(20px)}100%{opacity:1;transform:scale(1) translateY(0)}}@keyframes show{0%{opacity:0;transform:scale(0.4) translateY(20px)}100%{opacity:1;transform:scale(1) translateY(0)}}@-webkit-keyframes exit{0%{opacity:1;transform:scale(1) translateX(0)}100%{opacity:0;transform:scale(0.3) translateX(-24px)}}@keyframes exit{0%{opacity:1;transform:scale(1) translateX(0)}100%{opacity:0;transform:scale(0.3) translateX(-24px)}}:host([name-tag-position='bottom-right']) ::slotted(dyte-name-tag){left:auto;right:var(--dyte-space-3, 12px)}:host([name-tag-position='bottom-center']) ::slotted(dyte-name-tag){left:auto;right:auto}:host([name-tag-position='top-left']) ::slotted(dyte-name-tag){top:var(--dyte-space-3, 12px);bottom:auto}:host([name-tag-position='top-right']) ::slotted(dyte-name-tag){top:var(--dyte-space-3, 12px);right:var(--dyte-space-3, 12px);left:auto;bottom:auto}:host([name-tag-position='top-center']) ::slotted(dyte-name-tag){left:auto;right:auto;bottom:auto;top:var(--dyte-space-3, 12px)}";

const DyteScreenshareView = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Position of name tag */
    this.nameTagPosition = 'bottom-left';
    /** Variant */
    this.variant = 'solid';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    this.screenShareEnabled = false;
  }
  componentDidLoad() {
    this.peerChanged(this.peer);
  }
  disconnectedCallback() {
    var _a;
    this.screenShareListener &&
      ((_a = this.peer) === null || _a === void 0 ? void 0 : _a.removeListener('screenShareUpdate', this.screenShareListener));
  }
  peerChanged(peer) {
    if (peer != null) {
      this.screenShareListener = ({ screenShareEnabled, screenShareTracks }) => {
        const enabled = screenShareEnabled && screenShareTracks.video != null;
        writeTask(() => {
          this.screenShareEnabled = enabled;
        });
        if (enabled) {
          const stream = new MediaStream();
          stream.addTrack(screenShareTracks.video);
          if (typeof this.videoEl !== 'undefined') {
            this.videoEl.srcObject = stream;
            this.videoEl.play();
          }
        }
        else {
          this.videoEl.srcObject = undefined;
        }
      };
      this.screenShareListener(peer);
      peer.addListener('screenShareUpdate', this.screenShareListener);
    }
  }
  render() {
    return (h(Host, null, h("video", { ref: (el) => (this.videoEl = el), class: {
        visible: this.screenShareEnabled,
      }, playsInline: true, autoPlay: true, muted: true }), h("slot", null)));
  }
  static get watchers() { return {
    "peer": ["peerChanged"]
  }; }
};
DyteScreenshareView.style = dyteScreenshareViewCss;

export { DyteScreenshareView as dyte_screenshare_view };
