import { r as registerInstance, h, H as Host } from './index-da7bf46b.js';
import { s as shorten } from './string-739d5cc6.js';
import { d as defaultConfig, R as Render } from './index-560ccbe9.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';
import { g as gracefulStorage } from './graceful-storage-33bc316d.js';

const dyteSetupScreenCss = ":host{height:100%;width:100%;font-family:var(--dyte-font-family, sans-serif);display:flex;align-items:center;justify-content:center}.ctr{margin-left:auto;margin-right:auto;box-sizing:border-box;display:flex;width:66.666667%;max-width:1080px;align-items:center;padding-left:var(--dyte-space-4, 16px);padding-right:var(--dyte-space-4, 16px)}.ctr>div{display:flex;max-width:100%;flex:1 1 0%;flex-direction:column;align-items:center}dyte-button{height:auto;padding-top:var(--dyte-space-2, 8px);padding-bottom:var(--dyte-space-2, 8px);padding-left:var(--dyte-space-12, 48px);padding-right:var(--dyte-space-12, 48px);font-size:18px;min-height:var(--dyte-space-12, 48px)}h1{margin:var(--dyte-space-0, 0px);margin-bottom:var(--dyte-space-6, 24px);text-align:center;font-size:28px;font-weight:500;letter-spacing:-0.025em}input{margin-bottom:var(--dyte-space-10, 40px);display:block;height:var(--dyte-space-10, 40px);width:100%;max-width:var(--dyte-space-80, 320px);border-radius:var(--dyte-border-radius-sm, 4px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-bg-opacity));padding-left:var(--dyte-space-3, 12px);padding-right:var(--dyte-space-3, 12px);color:rgb(var(--dyte-colors-text-1000, 255 255 255));box-sizing:border-box;font-size:16px;outline:2px solid transparent;outline-offset:2px;transition-property:color, background-color, border-color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-text-decoration-color, -webkit-backdrop-filter;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-text-decoration-color, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}input::-moz-placeholder{color:rgb(var(--dyte-colors-text-600, 255 255 255 / 0.52))}input:-ms-input-placeholder{color:rgb(var(--dyte-colors-text-600, 255 255 255 / 0.52))}input::placeholder{color:rgb(var(--dyte-colors-text-600, 255 255 255 / 0.52))}input{border:var(--dyte-border-width-sm, 1px) solid rgb(var(--dyte-colors-background-600, 60 60 60))}input:focus{--tw-border-opacity:1;border-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-border-opacity))}dyte-spinner{color:rgb(var(--dyte-colors-text-1000, 255 255 255))}.controls{margin-top:var(--dyte-space-4, 16px);margin-bottom:var(--dyte-space-4, 16px);display:flex;align-items:center}:host([size='md']) .ctr,:host([size='sm']) .ctr{width:100%;flex-direction:column}:host([size='md']) .right,:host([size='sm']) .right{margin-top:var(--dyte-space-12, 48px)}:host([size='md']) .right h1,:host([size='sm']) .right h1{font-size:20px}:host([size='md']) dyte-button,:host([size='sm']) dyte-button{min-height:-webkit-min-content;min-height:-moz-min-content;min-height:min-content;font-size:16px}dyte-peer-view{max-width:100%}";

const DyteSetupScreen = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Config object */
    this.config = defaultConfig;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.isJoining = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      // NOTE(roerohan): Set display name from local storage if available.
      // If the name is '', `use meeting.self.name`.
      this.displayName = gracefulStorage.getItem('dyte-display-name') || meeting.self.name;
      // NOTE(roerohan): This is to update the name in the peer-view component,
      // since it uses `meeting.self.name`.
      meeting.self.setName(this.displayName);
    }
  }
  join() {
    var _a;
    if (this.displayName !== '') {
      this.isJoining = true;
      this.meeting.self.setName(this.displayName);
      gracefulStorage.setItem('dyte-display-name', this.displayName);
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.joinRoom();
    }
  }
  render() {
    var _a, _b;
    const disabled = this.displayName.trim() === '';
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (h(Host, null, h("div", { class: "ctr" }, h("div", { class: "left" }, h(Render, { element: "dyte-peer-view", defaults: defaults, props: { peer: (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self }, childProps: { peer: (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self }, deepProps: true }), h("div", { class: "controls" }, h("dyte-mic-toggle", { size: "sm", meeting: this.meeting }), h("dyte-camera-toggle", { size: "sm", meeting: this.meeting }))), h("div", { class: "right" }, h("h1", null, this.displayName.trim() === ''
      ? 'Hello there!'
      : `Hello ${shorten(this.displayName, 20)}!`), h("input", { placeholder: "Your name", value: this.displayName, onInput: (e) => {
        this.displayName = e.target.value;
      }, onKeyDown: (e) => {
        if (e.key === 'Enter') {
          this.join();
        }
      } }), h("dyte-button", { onClick: () => this.join(), disabled: disabled }, this.isJoining ? h("dyte-spinner", null) : 'Join')))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteSetupScreen.style = dyteSetupScreenCss;

export { DyteSetupScreen as dyte_setup_screen };
